package com.ruoyi.oa.mapper;

import java.util.List;
import com.ruoyi.oa.domain.CmcProjectSubContract;

/**
 * cmc项目分包合同Mapper接口
 * 
 * @author cmc
 * @date 2024-06-19
 */
public interface CmcProjectSubContractMapper 
{
    /**
     * 查询cmc项目分包合同
     * 
     * @param projectId cmc项目分包合同主键
     * @return cmc项目分包合同
     */
    public CmcProjectSubContract selectCmcProjectSubContractByProjectId(String projectId);

    /**
     * 查询cmc项目分包合同列表
     * 
     * @param cmcProjectSubContract cmc项目分包合同
     * @return cmc项目分包合同集合
     */
    public List<CmcProjectSubContract> selectCmcProjectSubContractList(CmcProjectSubContract cmcProjectSubContract);

    /**
     * 新增cmc项目分包合同
     * 
     * @param cmcProjectSubContract cmc项目分包合同
     * @return 结果
     */
    public int insertCmcProjectSubContract(CmcProjectSubContract cmcProjectSubContract);

    /**
     * 修改cmc项目分包合同
     * 
     * @param cmcProjectSubContract cmc项目分包合同
     * @return 结果
     */
    public int updateCmcProjectSubContract(CmcProjectSubContract cmcProjectSubContract);

    /**
     * 删除cmc项目分包合同
     * 
     * @param projectId cmc项目分包合同主键
     * @return 结果
     */
    public int deleteCmcProjectSubContractByProjectId(String projectId);

    /**
     * 批量删除cmc项目分包合同
     * 
     * @param subContractIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcProjectSubContractBySubContractIds(String[] subContractIds);
}
